=======
Credits
=======

Development Lead
----------------

* Niklas Bohn <nbohn@gfz-potsdam.de>

Contributors
------------

* Daniel Scheffler <daniel.scheffler@gfz-potsdam.de>
* Maximilian Brell <maximilian.brell@gfz-potsdam.de>
* René Preusker <rene.preusker@wew.fu-berlin.de>
* Hannes Diedrich
* André Hollstein
